[![PyPI][pypi-image]][pypi-link]

  [pypi-image]: https://img.shields.io/pypi/v/mkdocs-custommill.svg
  [pypi-link]: https://pypi.python.org/pypi/mkdocs-custommill

# CustomMill theme for [MkDocs](https://github.com/mkdocs/mkdocs/)
Another iteration on the awesome Windmill theme for MkDocs. This is permitted by the MIT License.

Highlights:
- Convenient navigation for larger documentation projects.
- Retains state of the navigation menu across page transitions.
- Deep nesting of documentation folders
- Search with term highlighting.
- User may search in a quick dropdown or load results in a full page.
- Default mkdocs theme within pages, including syntax highlighting.
- Custom coloring through sass

## Quick start

To install using `pip`:
``` sh
pip install mkdocs-custommill
```

To use in `mkdocs.yml`:
``` yaml
theme: custommill
```

## Demo and documentation

More details generated from the included docs are coming soon ;)

## Development

If doing development on `mkdocs-custommill`, check it out with
``` sh
git clone https://github.com/Siphalor/mkdocs-custommill/
cd mkdocs-custommill
```

